@@ -39,9 +39,16 @@ namespace logid::backend::raw {
         static constexpr int max_data_length = 32;
         typedef RawEventHandler EventHandler;
 
+        enum BusType {
+            USB,
+            Bluetooth,
+            OtherBus
+        };
+
         struct dev_info {
             int16_t vid;
             int16_t pid;
+            BusType bus_type;
         };
 
         RawDevice(std::string path, const std::shared_ptr<DeviceMonitor>& monitor);
@@ -57,6 +64,10 @@ namespace logid::backend::raw {
 
         [[nodiscard]] int16_t productId() const;
 
+        [[nodiscard]] BusType busType() const;
+
+        [[nodiscard]] bool isSubDevice() const;
+
         static std::vector<uint8_t> getReportDescriptor(const std::string& path);
 
         static std::vector<uint8_t> getReportDescriptor(int fd);
@@ -80,6 +91,8 @@ namespace logid::backend::raw {
 
         std::shared_ptr<IOMonitor> _io_monitor;
 
+        bool _sub_device = false;
+
         std::shared_ptr<EventHandlerList<RawDevice>> _event_handlers;
 
         void _handleEvent(const std::vector<uint8_t>& report);
